import 'dart:io';

import 'package:assets_audio_player/assets_audio_player.dart';
import 'package:awesome_dialog/awesome_dialog.dart';
import 'package:external_app_launcher/external_app_launcher.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get.dart';
import 'package:in_app_review/in_app_review.dart';
import 'package:in_app_update/in_app_update.dart';
import 'package:lottie/lottie.dart';
import 'package:onesignal_flutter/onesignal_flutter.dart';

import 'arbis_flutter_platform_interface.dart';

class ArbisFlutter {
  static arbisExitDialog({required Widget mediumNative}) {
    return AwesomeDialog(
      context: Get.context!,
      animType: AnimType.scale,
      dialogType: DialogType.warning,
      headerAnimationLoop: true,
      customHeader:
          Lottie.asset("packages/arbis_flutter/assets/41417-close.json"),
      padding: EdgeInsets.all(10.h),
      body: Column(
        children: [
          Text(
            "Do you want to exit?",
            style: TextStyle(fontWeight: FontWeight.bold),
          ),
          // Spacer(),
          SizedBox(
            height: 20.h,
          ),
          Row(
            children: [
              Expanded(
                child: InkWell(
                  onTap: () {
                    exit(0);
                  },
                  child: Container(
                    margin: EdgeInsets.all(10.h),
                    alignment: Alignment.center,
                    // width: 500.w,
                    padding: EdgeInsets.all(10.h),
                    decoration: BoxDecoration(
                        border: Border.all(color: Colors.grey),
                        color: Colors.white,
                        borderRadius: BorderRadius.all(Radius.circular(10))),
                    child: Text(
                      "Yes",
                      style: TextStyle(color: Colors.black, fontSize: 15.w),
                    ),
                  ),
                ),
              ),
              Expanded(
                child: InkWell(
                  onTap: () {
                    Get.back();
                  },
                  child: Container(
                    margin: EdgeInsets.all(10.h),
                    alignment: Alignment.center,
                    // width: 500.w,
                    padding: EdgeInsets.all(10.h),
                    decoration: BoxDecoration(
                        color: Colors.black,
                        borderRadius: BorderRadius.all(Radius.circular(10))),
                    child: Text(
                      "No",
                      style: TextStyle(color: Colors.white, fontSize: 15.w),
                    ),
                  ),
                ),
              )
            ],
          ),
          SizedBox(
            height: 20.h,
          ),
          mediumNative
        ],
      ),
      title: 'This is Ignored',
      desc: 'This is also Ignored',
    )..show();
  }

  static updateDialog(
      {required bool isPopup,
      required String appLogoApi,
      required String appNameApi,
      required String subtitleAppApi,
      required String appWebsiteUrl}) async {
    if (isPopup == true) {
      AssetsAudioPlayer.newPlayer().open(
        Audio("packages/arbis_flutter/assets/aa.wav"),
        autoStart: true,
        showNotification: false,
      );

      Get.defaultDialog(
          title: "",
          content: Stack(
            children: [
              Column(
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Text(
                        "Alert".tr,
                        style: TextStyle(
                            fontSize: 24.w, fontWeight: FontWeight.bold),
                      ),
                      const Text(
                        " (Ad)",
                        style: TextStyle(color: Colors.grey),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 20,
                  ),
                  if (appLogoApi.isEmpty)
                    Container(
                      decoration: const BoxDecoration(
                          borderRadius: BorderRadius.all(Radius.circular(20))),
                      child: Container(
                        decoration: const BoxDecoration(
                            borderRadius:
                                BorderRadius.all(Radius.circular(20))),
                        child: Image.asset(
                          appLogoApi,
                          height: 250.h,
                        ),
                      ),
                    )
                  else
                    Container(
                      decoration: BoxDecoration(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(30)),
                        boxShadow: [
                          BoxShadow(
                            color: Colors.black.withOpacity(0.3),
                            spreadRadius: 2,
                            blurRadius: 5,
                            offset: const Offset(
                                4, 10), // changes position of shadow
                          ),
                        ],
                      ),
                      child: ClipRRect(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(30)),
                        child: InkWell(
                          splashColor: Colors.transparent,
                          highlightColor: Colors.transparent,
                          onTap: () async {
                            var packageid = appWebsiteUrl.split("?id=");

                            await LaunchApp.openApp(
                                androidPackageName: packageid[1],
                                iosUrlScheme: 'pulsesecure://',
                                appStoreLink:
                                    'itms-apps://itunes.apple.com/us/app/pulse-secure/id945832041');
                            // launch(appWebsiteUrl);
                          },
                          child: Image.network(
                            appLogoApi,
                            fit: BoxFit.fill,
                            height: 190.h,
                            width: 190.h,
                          ),
                        ),
                      ),
                    ),
                ],
              ),
            ],
          ),
          actions: [
            Column(
              children: [
                SizedBox(
                  height: 20.h,
                ),
                Text(appNameApi.tr,
                    style: const TextStyle(
                        color: Colors.black, fontWeight: FontWeight.bold)),
                SizedBox(
                  height: 10.h,
                ),
                Text(subtitleAppApi.tr, textAlign: TextAlign.center),
                SizedBox(
                  height: 5.h,
                )
              ],
            )
          ],
          backgroundColor: Colors.white,
          titleStyle: const TextStyle(
              color: Colors.black, fontWeight: FontWeight.bold, height: 00),
          middleTextStyle: const TextStyle(
            color: Colors.white,
          ),
          confirm: Padding(
            padding: EdgeInsets.only(bottom: 10.h),
            child: Stack(
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    Container(
                      // height: 60.h,
                      decoration: const BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      width: 150.w,
                      child: Column(
                        children: [
                          InkWell(
                            splashColor: Colors.transparent,
                            highlightColor: Colors.transparent,
                            child: Container(
                              width: 150.w,
                              height: 50.h,
                              decoration: const BoxDecoration(
                                image: DecorationImage(
                                  image: AssetImage(
                                      "packages/arbis_flutter/assets/playstore.png"),
                                  fit: BoxFit.fitWidth,
                                  alignment: Alignment.topCenter,
                                ),
                              ),
                            ),
                            onTap: () async {
                              var packageid = appWebsiteUrl.split("?id=");
                              await LaunchApp.openApp(
                                  androidPackageName: packageid[1],
                                  iosUrlScheme: 'pulsesecure://',
                                  appStoreLink:
                                      'itms-apps://itunes.apple.com/us/app/pulse-secure/id945832041');
                            },
                          ),
                          InkWell(
                            splashColor: Colors.transparent,
                            highlightColor: Colors.transparent,
                            onTap: () {
                              Get.back();
                            },
                            child: Text(
                              "No Thanks".tr,
                              style: const TextStyle(
                                  color: Color(0xff007A3D),
                                  fontWeight: FontWeight.bold),
                            ),
                          ),
                        ],
                      ),
                    ),
                    SizedBox(
                      height: 20.h,
                    )
                  ],
                ),
              ],
            ),
          ),
          // confirm: Container(
          //   child: Text("Download App"),
          // ),
          radius: 10);
    }
  }

  static arbisAutoRate() {
    final InAppReview inAppReview = InAppReview.instance;

    WidgetsBinding.instance.addPostFrameCallback((_) async {
      await inAppReview.isAvailable();
    });

    Future<void> _requestReview() => inAppReview.requestReview();
    _requestReview();
  }


  static Future<void> arbicAutoUpdate() async {
    InAppUpdate.checkForUpdate().then((info) {}).catchError((e) {
      if (kDebugMode) {
        print(e.toString());
      }
    }).then((value) => {
          InAppUpdate.startFlexibleUpdate(),
        });
  }



  static Future<void> oneSignalNotification(
      {required String? oneSignalId}) async {
    OneSignal.shared.setAppId("$oneSignalId");
    OneSignal.shared
        .promptUserForPushNotificationPermission()
        .then((accepted) {});
  }



}
